==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/WelcomeScreen.java <==
package de.keksuccino.fancymenu;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import de.keksuccino.fancymenu.util.WebUtils;
import de.keksuccino.fancymenu.util.rendering.RenderingUtils;
import de.keksuccino.fancymenu.util.rendering.gui.GuiGraphics;
import de.keksuccino.fancymenu.util.rendering.gui.ModernScreen;
import de.keksuccino.fancymenu.util.rendering.text.markdown.ScrollableMarkdownRenderer;
import de.keksuccino.fancymenu.util.rendering.ui.tooltip.Tooltip;
import de.keksuccino.fancymenu.util.rendering.ui.widget.button.ExtendedButton;
import net.minecraft.class_1074;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_437;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class WelcomeScreen extends ModernScreen {

    private static final Logger LOGGER = LogManager.getLogger();
    private static final int HEADER_HEIGHT = 40;
    private static final int FOOTER_HEIGHT = 50;
    private static final int BORDER = 40;

    private final class_437 parent;
    private final class_2561 headline = class_2561.method_43471("fancymenu.welcome.screen.headline").method_27696(class_2583.field_24360.method_10982(true));
    private ScrollableMarkdownRenderer markdownRenderer;
    private final class_327 font = class_310.method_1551().field_1772;

    public WelcomeScreen(@Nullable class_437 parent) {
        super(class_2561.method_43471("fancymenu.welcome.screen.title"));
        this.parent = parent;
    }

    protected void method_25426() {

        int centerX = this.field_22789 / 2;
        int scrollWidth = this.field_22789 - BORDER * 2;
        int scrollHeight = this.field_22790 - HEADER_HEIGHT - FOOTER_HEIGHT;
        if (this.markdownRenderer == null) {
            this.markdownRenderer = new ScrollableMarkdownRenderer((float)(centerX - scrollWidth / 2), (float)HEADER_HEIGHT, (float)scrollWidth, (float)scrollHeight);
        } else {
            this.markdownRenderer.rebuild((float)(centerX - scrollWidth / 2), (float)HEADER_HEIGHT, (float)scrollWidth, (float)scrollHeight);
        }
        this.markdownRenderer.getMarkdownRenderer().setText("^^^\n\n\n" + class_1074.method_4662("fancymenu.welcome.screen.text") + "\n^^^");
        this.markdownRenderer.getMarkdownRenderer().setAutoLineBreakingEnabled(true);
        this.method_37063(this.markdownRenderer);

        this.method_37063(new ExtendedButton(centerX - 100, this.field_22790 - (FOOTER_HEIGHT / 2) - 10, 200, 20, class_2561.method_43471("fancymenu.welcome.screen.open_docs"), button -> {
            try {
                WebUtils.openWebLink("https://docs.fancymenu.net");
            } catch (Exception ex) {
                LOGGER.error("[FANCYMENU] Failed to open FancyMenu docs in WelcomeScreen!", ex);
            }
            FancyMenu.getOptions().showWelcomeScreen.setValue(false);
            this.method_25419();
        })).setTooltip(Tooltip.of(LocalizationUtils.splitLocalizedLines("fancymenu.welcome.screen.open_docs.tooltip")));

    }

    @Override
    public void render(@NotNull GuiGraphics graphics, int mouseX, int mouseY, float partial) {

        this.renderBackground(graphics, mouseX, mouseY, partial);

        super.render(graphics, mouseX, mouseY, partial);

        graphics.drawCenteredString(this.field_22793, this.headline, this.field_22789 / 2, (HEADER_HEIGHT / 2) - (this.field_22793.field_2000 / 2), -1);

    }

    public void renderBackground(@NotNull GuiGraphics graphics, int mouseX, int mouseY, float partial) {

        this.renderBackground(graphics);

        //Render header and footer separators
        RenderSystem.enableBlend();
        RenderingUtils.resetShaderColor(graphics);
        graphics.fillGradient(0, HEADER_HEIGHT, this.field_22789, HEADER_HEIGHT + 4, -16777216, 0);
        graphics.fillGradient(0, this.field_22790 - FOOTER_HEIGHT - 4, this.field_22789, this.field_22790 - FOOTER_HEIGHT, 0, -16777216);
        RenderingUtils.resetShaderColor(graphics);

    }

    @Override
    public boolean method_25401(double mouseX, double mouseY, double scrollDeltaY) {
        return this.markdownRenderer.method_25401(mouseX, mouseY, scrollDeltaY);
    }

    @Override
    public boolean method_25406(double mouseX, double mouseY, int button) {
        return this.markdownRenderer.method_25406(mouseX, mouseY, button);
    }

    @Override
    public void method_25419() {
        class_310.method_1551().method_1507(this.parent);
    }

    @Override
    public boolean method_25422() {
        return false;
    }

}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/WelcomeScreen.java <==
package de.keksuccino.fancymenu;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import de.keksuccino.fancymenu.util.WebUtils;
import de.keksuccino.fancymenu.util.rendering.text.markdown.ScrollableMarkdownRenderer;
import de.keksuccino.fancymenu.util.rendering.ui.tooltip.Tooltip;
import de.keksuccino.fancymenu.util.rendering.ui.widget.button.ExtendedButton;
import net.minecraft.class_1074;
import net.minecraft.class_11909;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_437;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class WelcomeScreen extends class_437 {

    private static final Logger LOGGER = LogManager.getLogger();
    private static final int HEADER_HEIGHT = 40;
    private static final int FOOTER_HEIGHT = 50;
    private static final int BORDER = 40;

    private final class_437 parent;
    private final class_2561 headline = class_2561.method_43471("fancymenu.welcome.screen.headline").method_27696(class_2583.field_24360.method_10982(true));
    private ScrollableMarkdownRenderer markdownRenderer;
    private final class_327 font = class_310.method_1551().field_1772;

    public WelcomeScreen(@Nullable class_437 parent) {
        super(class_2561.method_43471("fancymenu.welcome.screen.title"));
        this.parent = parent;
    }

    protected void method_25426() {

        int centerX = this.field_22789 / 2;
        int scrollWidth = this.field_22789 - BORDER * 2;
        int scrollHeight = this.field_22790 - HEADER_HEIGHT - FOOTER_HEIGHT;
        if (this.markdownRenderer == null) {
            this.markdownRenderer = new ScrollableMarkdownRenderer((float)(centerX - scrollWidth / 2), (float)HEADER_HEIGHT, (float)scrollWidth, (float)scrollHeight);
        } else {
            this.markdownRenderer.rebuild((float)(centerX - scrollWidth / 2), (float)HEADER_HEIGHT, (float)scrollWidth, (float)scrollHeight);
        }
        this.markdownRenderer.getMarkdownRenderer().setText("^^^\n\n\n" + class_1074.method_4662("fancymenu.welcome.screen.text") + "\n^^^");
        this.markdownRenderer.getMarkdownRenderer().setAutoLineBreakingEnabled(true);
        this.method_37063(this.markdownRenderer);

        this.method_37063(new ExtendedButton(centerX - 100, this.field_22790 - (FOOTER_HEIGHT / 2) - 10, 200, 20, class_2561.method_43471("fancymenu.welcome.screen.open_docs"), button -> {
            try {
                WebUtils.openWebLink("https://docs.fancymenu.net");
            } catch (Exception ex) {
                LOGGER.error("[FANCYMENU] Failed to open FancyMenu docs in WelcomeScreen!", ex);
            }
            FancyMenu.getOptions().showWelcomeScreen.setValue(false);
            this.method_25419();
        })).setTooltip(Tooltip.of(LocalizationUtils.splitLocalizedLines("fancymenu.welcome.screen.open_docs.tooltip")));

    }

    @Override
    public void method_25394(@NotNull class_332 graphics, int mouseX, int mouseY, float partial) {

        super.method_25394(graphics, mouseX, mouseY, partial);

        graphics.method_27534(this.field_22793, this.headline, this.field_22789 / 2, (HEADER_HEIGHT / 2) - (this.field_22793.field_2000 / 2), -1);

    }

    @Override
    public void method_25420(@NotNull class_332 graphics, int mouseX, int mouseY, float partial) {

        super.method_25420(graphics, mouseX, mouseY, partial);

        //Render header and footer separators
         
        graphics.method_25296(0, HEADER_HEIGHT, this.field_22789, HEADER_HEIGHT + 4, -16777216, 0);
        graphics.method_25296(0, this.field_22790 - FOOTER_HEIGHT - 4, this.field_22789, this.field_22790 - FOOTER_HEIGHT, 0, -16777216);

    }

    @Override
    public boolean method_25401(double mouseX, double mouseY, double scrollDeltaX, double scrollDeltaY) {
        return this.markdownRenderer.method_25401(mouseX, mouseY, scrollDeltaX, scrollDeltaY);
    }

    @Override
    public boolean method_25406(class_11909 event) {
        return this.markdownRenderer.method_25406(event);
    }

    @Override
    public void method_25419() {
        class_310.method_1551().method_1507(this.parent);
    }

    @Override
    public boolean method_25422() {
        return false;
    }

}
